#!/usr/bin/env python
# -*- coding: utf-8 -*-

# # Données INSEE
# 
# Prétraitement des données IRIS.

# In[1]:


from jyquickhelper import add_notebook_menu
add_notebook_menu()


# ## Données carroyées population avec longitude, latitude
# 
# Les données carrroyées sont disponibles à l'adresse suivante [Données carroyées à 200m sur la population](https://www.data.gouv.fr/fr/datasets/donnees-carroyees-a-200m-sur-la-population/#_) sous la forme de shapefile. On suppose que les données ont été téléchargées et décompressées. Le code suivant montre comme les lire. Ces données ne contiennent que les données de populations de 2010.

# In[2]:


import pandas
carr = pandas.read_csv("c:/temp/insee/carroyage_insee_metro.csv")


# In[3]:


carr.head()


# On convertit le dataframe en [geodataframe](http://geopandas.org/data_structures.html).

# In[4]:


import geopandas as gpd
import shapely.wkt

geometry = carr['WKT'].map(shapely.wkt.loads)
carr = carr.drop('WKT', axis=1)
crs = {'init': 'epsg:4326'}
gcarr = gpd.GeoDataFrame(carr, crs=crs, geometry=geometry)


# In[5]:


gcarr.head().T


# ## Données IRIS population
# 
# Les données IRIS fournissent d'autres informations sur un quadrillage plus gros du territoire français :
# 
# * [contours IRIS](https://www.data.gouv.fr/fr/datasets/contour-des-iris-insee-tout-en-un/#_) - 348Mo
# * [population](https://www.insee.fr/fr/statistiques/2386737) - 86Mo
# * [revenus](https://www.insee.fr/fr/statistiques/2673683) - 4Mo
# * [logements](https://www.data.gouv.fr/fr/datasets/base-des-logements-france-iris/) - 5Mo
# * [activités](https://www.insee.fr/fr/statistiques/2386631) - 36Mo

# ### Contours

# In[6]:


import os
os.listdir("C:/temp/insee/iris_evol_pop_2013")


# In[7]:


import geopandas
geoiris = geopandas.read_file("c:/temp/insee/iris_evol_pop_2013/iris-2013-01-01.shp")


# In[8]:


geoiris.head()


# ### CAF

# In[9]:


import pandas
var = pandas.read_excel("c:/temp/insee/beneficiaires_CAF_31-12-2016.xls", 
                        skiprows=5, sheet_name="Variables")
var.head(n=15)


# In[10]:


caf = pandas.read_excel("c:/temp/insee/beneficiaires_CAF_31-12-2016.xls", 
                        skiprows=5, sheet_name="IRIS")
caf.head().T.head(n=15)


# ## Extraire les carreaux ou codegeo

# In[11]:


records = [
    dict(lieu='Paris', Lat=48.866667, Lon=2.333333),
    dict(lieu='Charleville', Lat=49.76208500000001, Lon=4.726095999999984),
]
df = pandas.DataFrame(records)
df


# In[12]:


from shapely.geometry import Point
geometry = [Point(xy) for xy in zip(df.Lon, df.Lat)]
df = df.drop(['Lon', 'Lat'], axis=1)
crs = {'init': 'epsg:4326'}
gdf = geopandas.GeoDataFrame(df, crs=crs, geometry=geometry)
gdf


# In[13]:


fusion = geopandas.sjoin(gdf, geoiris)


# In[14]:


fusion


# Même chose avec les données carroyées. Ca prend un petit peu de temps.

# In[15]:


fusion = geopandas.sjoin(gdf, gcarr)


# In[16]:


fusion


# On peut changer l'opérateur appliqué d'*intersection* à *contenu* (``op='within'``) selon la fusion souhaitée. Le code passe par une double boucle [sjoin](https://github.com/geopandas/geopandas/blob/master/geopandas/tools/sjoin.py) qui utilise des boucles avec des index type [R-tree](http://toblerity.org/rtree/#).

# In[17]: